#include <avr/io.h>
#include <avr/interrupt.h>
#define F_CPU 16000000
#include <util/delay.h>

unsigned int octava[8] = {
	110,  //DO
	96,   //RE
	86,   //MI
	80,   //FA
	70,   //SOL
	62,   //LA
	54,   //SI
	50    //DO
};

int adc_read(uint8_t channel) {	
	
	ADMUX = (ADMUX & 0xE0)|channel; // keeps first three bits and mark channel for read
	
	ADCSRA |= (1 << ADSC);		// starts a new conversion
	while (!(ADCSRA  & (1 << ADIF)));	
	
	return ADC;					// returns the ADC value of the channel
}

ISR(TIMER0_COMPA_vect) {
	int i;
	for (i = 0; i < 8; i++)
	{
		int val = adc_read(i);	
		if (val > 1023) 
		{		
			OCR2A = octava[i];
			TCCR2A |= (1 << COM2A0);
		}
		if (val < 1023)
		{
			OCR2A = 255;
			TCCR2A &= ~(1 << COM2A0);
		}
		break;
	}
}

void timer_init()
{
	TCCR2A |= (1 << COM2A1) | (1 << WGM21) | (1 << WGM20);
	TCCR2B |= (1 << CS20);
	TIMSK2 |= (1 << OCIE2A); //interrupt 
	OCR2A = 255;

}

void pwm_init()
{
	TCCR1A |= (1 << COM1A0) | (1 << WGM10);
	TCCR1B |= _BV(WGM13) | _BV(CS12);

}

void adc_init(){
 
	ADCSRA |= ((1<<ADPS2)|(1<<ADPS1)|(1<<ADPS0));    //16Mhz/128 = 125Khz the ADC reference clock
	
	ADCSRA |= (1<<ADIE) | (1 << ADATE);		
	ADMUX |= (1<<REFS0);                
		
	ADCSRA |= (1<<ADEN);                
	ADCSRA |= (1<<ADSC);                
	ADCSRB = 0;							        
	
} 



int main(void)
{

	DDRD |= (1 << PD6);
	adc_init();
	timer_init();
	pwm_init();
	
	sei();
	while (1)
	{
		;
	}
	
	return 0;
}
